==> qtsmbstatus_2.1.3.orig.tar.gz: qtsmbstatus-2.1.3/client/tr/qtsmbstatus_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="de">
<context>
    <name></name>
    <message>
        <source></source>
        <translation>Project-Id-Version: 2.1.2
Report-Msgid-Bugs-To: 
POT-Creation-Date: 2008-11-12 21:25+0200
PO-Revision-Date: 2009-09-26 16:54+0000
Last-Translator: Till Freier &lt;till@thoran.eu&gt;
Language-Team: LANGUAGE &lt;LL@li.org&gt;
MIME-Version: 1.0
Content-Type: text/plain; charset=UTF-8
Content-Transfer-Encoding: 8bit
X-Launchpad-Export-Date: 2009-12-26 10:24+0000
X-Generator: Launchpad (build Unknown)
</translation>
    </message>
</context>
<context>
    <name>LogForm</name>
    <message>
        <source>Date</source>
        <translation>Datum</translation>
    </message>
    <message>
        <source>Machine</source>
        <translation>Maschine</translation>
    </message>
    <message>
        <source>User</source>
        <translation>User</translation>
    </message>
    <message>
        <source>Service</source>
        <translation>Dienst</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Belegungstyp</translation>
    </message>
    <message>
        <source>Open File</source>
        <translation>Öffne Datei</translation>
    </message>
</context>
<context>
    <name>MainWindows</name>
    <message>
        <source>Show CIFS/SMB activities</source>
        <translation>Zeige CIFS/SMB aktivitäten</translation>
    </message>
    <message>
        <source>Configure</source>
        <translation>Einrichten</translation>
    </message>
    <message>
        <source>Minimize</source>
        <translation>Minimieren</translation>
    </message>
    <message>
        <source>Quit</source>
        <translation>beenden</translation>
    </message>
    <message>
        <source>Restore</source>
        <translation>Wiederherstellen</translation>
    </message>
    <message>
        <source>Thanks to:</source>
        <translation>Dank an:</translation>
    </message>
    <message>
        <source>This program is licensed to you under the terms of the GNU General Public License version 2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Find text</source>
        <translation>Text suchen</translation>
    </message>
    <message>
        <source>Text not found.</source>
        <translation>Text nicht gefunden.</translation>
    </message>
    <message>
        <source>User %1 has opened share %2 (%3)</source>
        <translation>Benutzer %1 hat die Datei(en) %2 (%3) geöffnet</translation>
    </message>
    <message>
        <source>User %1 has opened file %2 (%3)</source>
        <translation>Benutzer %1 hat dei Datei(en) %2 (%3) geöffnet</translation>
    </message>
    <message>
        <source>CIFS/SMB activities</source>
        <translation>CIFS/SMB aktivitäten</translation>
    </message>
    <message>
        <source>Message to send</source>
        <translation>Nachricht zum Senden</translation>
    </message>
    <message>
        <source>Message to send to %1:</source>
        <translation>nachricht zu %1 senden:</translation>
    </message>
    <message>
        <source>Do you really want to disconnect user %1 ?</source>
        <translation>Möchten Sie wirklich die Verbindung von User %1 beenden?</translation>
    </message>
    <message>
        <source>&amp;Yes</source>
        <translation>&amp;Ja</translation>
    </message>
    <message>
        <source>&amp;No</source>
        <translation>&amp;Nein</translation>
    </message>
    <message>
        <source>Properties</source>
        <translation>Eigenschaften</translation>
    </message>
    <message>
        <source>Send out message to all users</source>
        <translation>Sende Nachricht an alle Benutzer</translation>
    </message>
    <message>
        <source>Send out message to</source>
        <translation>Sende Nachricht an</translation>
    </message>
    <message>
        <source>Disconnect user</source>
        <translation>Schliesse Verbindung von User</translation>
    </message>
    <message>
        <source>Update is available</source>
        <translation>Aktualisierung verfügbar</translation>
    </message>
    <message>
        <source>A new release of %1 is available</source>
        <translation>Es ist eine neue Version von %1 verfügbar</translation>
    </message>
    <message>
        <source>You can download it here: %1</source>
        <translation>Sie können sie hier herunterladen: %1</translation>
    </message>
</context>
<context>
    <name>configure</name>
    <message>
        <source>Configure</source>
        <translation>Einrichten</translation>
    </message>
    <message>
        <source>Smbstatus</source>
        <translation>Smbstatus</translation>
    </message>
    <message>
        <source>&lt;p align=&quot;right&quot;&gt;Interval:&lt;/p&gt;</source>
        <translation>&lt;p align=&quot;right&quot;&gt;Interval:&lt;/p&gt;</translation>
    </message>
    <message>
        <source>Interval between smbstatus requests in seconds, (interval &gt; 2)</source>
        <translation>Intervall zwischen smbstatus anfragen in Sekunden, (intervall &gt;2)</translation>
    </message>
    <message>
        <source>Show hidden shares (share$)</source>
        <translation>Zeige verstecke Anteile (share$)</translation>
    </message>
    <message>
        <source>Show hidden shares</source>
        <translation>Zeige verstecke Anteile</translation>
    </message>
    <message>
        <source>Notifications and log</source>
        <translation>Benachrichten und loggen</translation>
    </message>
    <message>
        <source>Limit log:</source>
        <translation>Begrenzter Log:</translation>
    </message>
    <message>
        <source>days</source>
        <translation>Tage</translation>
    </message>
    <message>
        <source>Iconize QtSmbstatus in system tray</source>
        <translation>Erschaffe QtSmbstatus Icon im System menu</translation>
    </message>
    <message>
        <source>Show activities in &quot;balloon messages&quot;</source>
        <translation>Zeige Aktivität in &quot;Ballon Nachrichten&quot;</translation>
    </message>
    <message>
        <source>Status notification messages</source>
        <translation>Status Benachrichtigung</translation>
    </message>
    <message>
        <source>Log SMB/CIFS activities</source>
        <translation>Logge SMB/CIFS tätigkeiten</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <source>Misc</source>
        <translation>Sonstiges</translation>
    </message>
    <message>
        <source>Automatically Check for updates</source>
        <translation>Automatische Updateprüfung</translation>
    </message>
    <message>
        <source>A new release is available</source>
        <translation>Eine neue Version ist verfügbar</translation>
    </message>
    <message>
        <source>Connection</source>
        <translation>Verbindung</translation>
    </message>
    <message>
        <source>&lt;p align=&quot;right&quot;&gt;Default Username:&lt;/p&gt;</source>
        <translation>&lt;p align=&quot;right&quot;&gt;Standart Username:&lt;/p&gt;</translation>
    </message>
    <message>
        <source>Autoconnect on qtsmbstatus startup</source>
        <translation>Automatische Verbindung bei qtsmbstatus start</translation>
    </message>
    <message>
        <source>Autoconnect</source>
        <translation>Automatisches Verbinden</translation>
    </message>
    <message>
        <source>&lt;p align=&quot;right&quot;&gt;Default host address:&lt;/p&gt;</source>
        <translation>&lt;p align=&quot;right&quot;&gt;Standart Rechner Adresse:&lt;/p&gt;</translation>
    </message>
    <message>
        <source>Username (default :  username = root)</source>
        <translation>Benutzername (default: username = root)</translation>
    </message>
    <message>
        <source>Host Address</source>
        <translation>Rechneradresse</translation>
    </message>
</context>
<context>
    <name>form_smbstatus</name>
    <message>
        <source>qtsmbstatus</source>
        <translation>qtsmbstatus</translation>
    </message>
    <message>
        <source>Host:</source>
        <translation>Host:</translation>
    </message>
    <message>
        <source>Connect/Disconnect</source>
        <translation>Verbinden/Trennen</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Datei</translation>
    </message>
    <message>
        <source>&amp;Search</source>
        <translation>&amp;Suche</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Hilfe</translation>
    </message>
    <message>
        <source>&amp;About QtSmbstatus</source>
        <translation>&amp;Über QtSmbstatus</translation>
    </message>
    <message>
        <source>About QtSmbstatus</source>
        <translation>Über QtSmbstatus</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>Über &amp;Qt</translation>
    </message>
    <message>
        <source>About Qt</source>
        <translation>Über Qt</translation>
    </message>
    <message>
        <source>&amp;Configure client</source>
        <translation>&amp;Einstellungen Client</translation>
    </message>
    <message>
        <source>Configure QtSmbstatus client</source>
        <translation>Einstellung QtSmbstatus Clients</translation>
    </message>
    <message>
        <source>&amp;Machine</source>
        <translation>&amp;Maschine</translation>
    </message>
    <message>
        <source>Search machine</source>
        <translation>Suche Maschine</translation>
    </message>
    <message>
        <source>&amp;User</source>
        <translation>&amp;Benutzer</translation>
    </message>
    <message>
        <source>Search user</source>
        <translation>Suche User</translation>
    </message>
    <message>
        <source>Share &amp;open</source>
        <translation>Teilen &amp;öffenen</translation>
    </message>
    <message>
        <source>Search share open</source>
        <translation>Suche geöffnete Anteile</translation>
    </message>
    <message>
        <source>&amp;Locked file</source>
        <translation>&amp;verschlossene File</translation>
    </message>
    <message>
        <source>Search file open</source>
        <translation>Suche geöffnete Datei</translation>
    </message>
    <message>
        <source>&amp;Next</source>
        <translation>&amp;weiter</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Nächstes</translation>
    </message>
    <message>
        <source>F3</source>
        <translation>F3</translation>
    </message>
    <message>
        <source>&amp;Find text</source>
        <translation>&amp;Finde Text</translation>
    </message>
    <message>
        <source>Find text</source>
        <translation>Text suchen</translation>
    </message>
    <message>
        <source>F5</source>
        <translation>F5</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;beenden</translation>
    </message>
    <message>
        <source>Quit QtSmbstatus</source>
        <translation>Beende QtSmbstatus</translation>
    </message>
    <message>
        <source>&amp;Show CIFS/SMB activities</source>
        <translation>&amp;Zeige CIFS/SMB aktivitäten</translation>
    </message>
    <message>
        <source>Co&amp;nnect</source>
        <translation>Verbi&amp;nde</translation>
    </message>
</context>
<context>
    <name>logform</name>
    <message>
        <source>View Activities</source>
        <translation>Zeige Aktivitäten</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>Leeren/Zurücksetzen</translation>
    </message>
    <message>
        <source>Save log</source>
        <translation>Log speichern</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Schliessen</translation>
    </message>
    <message>
        <source>View/hide shares</source>
        <translation>Zeige/Verstecke Anteile</translation>
    </message>
    <message>
        <source>View/hide files</source>
        <translation>Zeige/verstecke Dateien</translation>
    </message>
    <message>
        <source>Filter:</source>
        <translation>Filter:</translation>
    </message>
</context>
<context>
    <name>login_dialog</name>
    <message>
        <source>Connect to qtsmbstatus server</source>
        <translation>Verbinde zum qtsmbstatus Server</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Username</translation>
    </message>
    <message>
        <source>root</source>
        <translation>root</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Passwort</translation>
    </message>
    <message>
        <source>login</source>
        <translation>Anmelden</translation>
    </message>
    <message>
        <source>exit</source>
        <translation>Beenden</translation>
    </message>
</context>
<context>
    <name>main_windows</name>
    <message>
        <source>Connect</source>
        <translation>Verbunden</translation>
    </message>
    <message>
        <source>Connection in progress on %1</source>
        <translation>Verbindung wird aufgebaut bei %1</translation>
    </message>
    <message>
        <source>Connected to host</source>
        <translation>Verbunden mit Host</translation>
    </message>
    <message>
        <source>Connection closed</source>
        <translation>Verbindung getrennt</translation>
    </message>
    <message>
        <source>Disconnect</source>
        <translation>Getrennt</translation>
    </message>
    <message>
        <source>Invalid login or password !</source>
        <translation>Falscher Login oder Passwort !</translation>
    </message>
</context>
</TS>

==> qtsmbstatus_2.2.1.orig.tar.gz: qtsmbstatus-2.2.1/client/tr/qtsmbstatus_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="de">
<context>
    <name></name>
    <message>
        <source></source>
        <translation>Project-Id-Version: 2.1.2
Report-Msgid-Bugs-To: 
POT-Creation-Date: 2008-11-12 21:25+0200
PO-Revision-Date: 2009-09-26 16:54+0000
Last-Translator: Till Freier &lt;till@thoran.eu&gt;
Language-Team: LANGUAGE &lt;LL@li.org&gt;
MIME-Version: 1.0
Content-Type: text/plain; charset=UTF-8
Content-Transfer-Encoding: 8bit
X-Launchpad-Export-Date: 2009-12-26 10:24+0000
X-Generator: Launchpad (build Unknown)
</translation>
    </message>
</context>
<context>
    <name>LogForm</name>
    <message>
        <source>Date</source>
        <translation>Datum</translation>
    </message>
    <message>
        <source>Machine</source>
        <translation>Maschine</translation>
    </message>
    <message>
        <source>User</source>
        <translation>User</translation>
    </message>
    <message>
        <source>Service</source>
        <translation>Dienst</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Belegungstyp</translation>
    </message>
    <message>
        <source>Open File</source>
        <translation>Öffne Datei</translation>
    </message>
</context>
<context>
    <name>MainWindows</name>
    <message>
        <source>Show CIFS/SMB activities</source>
        <translation>Zeige CIFS/SMB aktivitäten</translation>
    </message>
    <message>
        <source>Configure</source>
        <translation>Einrichten</translation>
    </message>
    <message>
        <source>Minimize</source>
        <translation>Minimieren</translation>
    </message>
    <message>
        <source>Quit</source>
        <translation>beenden</translation>
    </message>
    <message>
        <source>Restore</source>
        <translation>Wiederherstellen</translation>
    </message>
    <message>
        <source>Thanks to:</source>
        <translation>Dank an:</translation>
    </message>
    <message>
        <source>This program is licensed to you under the terms of the GNU General Public License version 2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Find text</source>
        <translation>Text suchen</translation>
    </message>
    <message>
        <source>Text not found.</source>
        <translation>Text nicht gefunden.</translation>
    </message>
    <message>
        <source>User %1 has opened share %2 (%3)</source>
        <translation>Benutzer %1 hat die Datei(en) %2 (%3) geöffnet</translation>
    </message>
    <message>
        <source>User %1 has opened file %2 (%3)</source>
        <translation>Benutzer %1 hat dei Datei(en) %2 (%3) geöffnet</translation>
    </message>
    <message>
        <source>CIFS/SMB activities</source>
        <translation>CIFS/SMB aktivitäten</translation>
    </message>
    <message>
        <source>Message to send</source>
        <translation>Nachricht zum Senden</translation>
    </message>
    <message>
        <source>Message to send to %1:</source>
        <translation>nachricht zu %1 senden:</translation>
    </message>
    <message>
        <source>Do you really want to disconnect user %1 ?</source>
        <translation>Möchten Sie wirklich die Verbindung von User %1 beenden?</translation>
    </message>
    <message>
        <source>&amp;Yes</source>
        <translation>&amp;Ja</translation>
    </message>
    <message>
        <source>&amp;No</source>
        <translation>&amp;Nein</translation>
    </message>
    <message>
        <source>Properties</source>
        <translation>Eigenschaften</translation>
    </message>
    <message>
        <source>Send out message to all users</source>
        <translation>Sende Nachricht an alle Benutzer</translation>
    </message>
    <message>
        <source>Send out message to</source>
        <translation>Sende Nachricht an</translation>
    </message>
    <message>
        <source>Disconnect user</source>
        <translation>Schliesse Verbindung von User</translation>
    </message>
    <message>
        <source>Update is available</source>
        <translation>Aktualisierung verfügbar</translation>
    </message>
    <message>
        <source>A new release of %1 is available</source>
        <translation>Es ist eine neue Version von %1 verfügbar</translation>
    </message>
    <message>
        <source>You can download it here: %1</source>
        <translation>Sie können sie hier herunterladen: %1</translation>
    </message>
</context>
<context>
    <name>configure</name>
    <message>
        <source>Configure</source>
        <translation>Einrichten</translation>
    </message>
    <message>
        <source>Smbstatus</source>
        <translation>Smbstatus</translation>
    </message>
    <message>
        <source>&lt;p align=&quot;right&quot;&gt;Interval:&lt;/p&gt;</source>
        <translation>&lt;p align=&quot;right&quot;&gt;Interval:&lt;/p&gt;</translation>
    </message>
    <message>
        <source>Interval between smbstatus requests in seconds, (interval &gt; 2)</source>
        <translation>Intervall zwischen smbstatus anfragen in Sekunden, (intervall &gt;2)</translation>
    </message>
    <message>
        <source>Show hidden shares (share$)</source>
        <translation>Zeige verstecke Anteile (share$)</translation>
    </message>
    <message>
        <source>Show hidden shares</source>
        <translation>Zeige verstecke Anteile</translation>
    </message>
    <message>
        <source>Notifications and log</source>
        <translation>Benachrichten und loggen</translation>
    </message>
    <message>
        <source>Limit log:</source>
        <translation>Begrenzter Log:</translation>
    </message>
    <message>
        <source>days</source>
        <translation>Tage</translation>
    </message>
    <message>
        <source>Iconize QtSmbstatus in system tray</source>
        <translation>Erschaffe QtSmbstatus Icon im System menu</translation>
    </message>
    <message>
        <source>Show activities in &quot;balloon messages&quot;</source>
        <translation>Zeige Aktivität in &quot;Ballon Nachrichten&quot;</translation>
    </message>
    <message>
        <source>Status notification messages</source>
        <translation>Status Benachrichtigung</translation>
    </message>
    <message>
        <source>Log SMB/CIFS activities</source>
        <translation>Logge SMB/CIFS tätigkeiten</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <source>Misc</source>
        <translation>Sonstiges</translation>
    </message>
    <message>
        <source>Automatically Check for updates</source>
        <translation>Automatische Updateprüfung</translation>
    </message>
    <message>
        <source>A new release is available</source>
        <translation>Eine neue Version ist verfügbar</translation>
    </message>
    <message>
        <source>Connection</source>
        <translation>Verbindung</translation>
    </message>
    <message>
        <source>&lt;p align=&quot;right&quot;&gt;Default Username:&lt;/p&gt;</source>
        <translation>&lt;p align=&quot;right&quot;&gt;Standart Username:&lt;/p&gt;</translation>
    </message>
    <message>
        <source>Autoconnect on qtsmbstatus startup</source>
        <translation>Automatische Verbindung bei qtsmbstatus start</translation>
    </message>
    <message>
        <source>Autoconnect</source>
        <translation>Automatisches Verbinden</translation>
    </message>
    <message>
        <source>&lt;p align=&quot;right&quot;&gt;Default host address:&lt;/p&gt;</source>
        <translation>&lt;p align=&quot;right&quot;&gt;Standart Rechner Adresse:&lt;/p&gt;</translation>
    </message>
    <message>
        <source>Username (default :  username = root)</source>
        <translation>Benutzername (default: username = root)</translation>
    </message>
    <message>
        <source>Host Address</source>
        <translation>Rechneradresse</translation>
    </message>
</context>
<context>
    <name>form_smbstatus</name>
    <message>
        <source>qtsmbstatus</source>
        <translation>qtsmbstatus</translation>
    </message>
    <message>
        <source>Host:</source>
        <translation>Host:</translation>
    </message>
    <message>
        <source>Connect/Disconnect</source>
        <translation>Verbinden/Trennen</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Datei</translation>
    </message>
    <message>
        <source>&amp;Search</source>
        <translation>&amp;Suche</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Hilfe</translation>
    </message>
    <message>
        <source>&amp;About QtSmbstatus</source>
        <translation>&amp;Über QtSmbstatus</translation>
    </message>
    <message>
        <source>About QtSmbstatus</source>
        <translation>Über QtSmbstatus</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>Über &amp;Qt</translation>
    </message>
    <message>
        <source>About Qt</source>
        <translation>Über Qt</translation>
    </message>
    <message>
        <source>&amp;Configure client</source>
        <translation>&amp;Einstellungen Client</translation>
    </message>
    <message>
        <source>Configure QtSmbstatus client</source>
        <translation>Einstellung QtSmbstatus Clients</translation>
    </message>
    <message>
        <source>&amp;Machine</source>
        <translation>&amp;Maschine</translation>
    </message>
    <message>
        <source>Search machine</source>
        <translation>Suche Maschine</translation>
    </message>
    <message>
        <source>&amp;User</source>
        <translation>&amp;Benutzer</translation>
    </message>
    <message>
        <source>Search user</source>
        <translation>Suche User</translation>
    </message>
    <message>
        <source>Share &amp;open</source>
        <translation>Teilen &amp;öffenen</translation>
    </message>
    <message>
        <source>Search share open</source>
        <translation>Suche geöffnete Anteile</translation>
    </message>
    <message>
        <source>&amp;Locked file</source>
        <translation>&amp;verschlossene File</translation>
    </message>
    <message>
        <source>Search file open</source>
        <translation>Suche geöffnete Datei</translation>
    </message>
    <message>
        <source>&amp;Next</source>
        <translation>&amp;weiter</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Nächstes</translation>
    </message>
    <message>
        <source>F3</source>
        <translation>F3</translation>
    </message>
    <message>
        <source>&amp;Find text</source>
        <translation>&amp;Finde Text</translation>
    </message>
    <message>
        <source>Find text</source>
        <translation>Text suchen</translation>
    </message>
    <message>
        <source>F5</source>
        <translation>F5</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;beenden</translation>
    </message>
    <message>
        <source>Quit QtSmbstatus</source>
        <translation>Beende QtSmbstatus</translation>
    </message>
    <message>
        <source>&amp;Show CIFS/SMB activities</source>
        <translation>&amp;Zeige CIFS/SMB aktivitäten</translation>
    </message>
    <message>
        <source>Co&amp;nnect</source>
        <translation>Verbi&amp;nde</translation>
    </message>
</context>
<context>
    <name>logform</name>
    <message>
        <source>View Activities</source>
        <translation>Zeige Aktivitäten</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>Leeren/Zurücksetzen</translation>
    </message>
    <message>
        <source>Save log</source>
        <translation>Log speichern</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Schliessen</translation>
    </message>
    <message>
        <source>View/hide shares</source>
        <translation>Zeige/Verstecke Anteile</translation>
    </message>
    <message>
        <source>View/hide files</source>
        <translation>Zeige/verstecke Dateien</translation>
    </message>
    <message>
        <source>Filter:</source>
        <translation>Filter:</translation>
    </message>
</context>
<context>
    <name>login_dialog</name>
    <message>
        <source>Connect to qtsmbstatus server</source>
        <translation>Verbinde zum qtsmbstatus Server</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Username</translation>
    </message>
    <message>
        <source>root</source>
        <translation>root</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Passwort</translation>
    </message>
    <message>
        <source>login</source>
        <translation>Anmelden</translation>
    </message>
    <message>
        <source>exit</source>
        <translation>Beenden</translation>
    </message>
</context>
<context>
    <name>main_windows</name>
    <message>
        <source>Connect</source>
        <translation>Verbunden</translation>
    </message>
    <message>
        <source>Connection in progress on %1</source>
        <translation>Verbindung wird aufgebaut bei %1</translation>
    </message>
    <message>
        <source>Connected to host</source>
        <translation>Verbunden mit Host</translation>
    </message>
    <message>
        <source>Connection closed</source>
        <translation>Verbindung getrennt</translation>
    </message>
    <message>
        <source>Disconnect</source>
        <translation>Getrennt</translation>
    </message>
    <message>
        <source>Invalid login or password !</source>
        <translation>Falscher Login oder Passwort !</translation>
    </message>
    <message>
        <source>The server certificate doesn&apos;t contain valid data or expired !</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The authenticity of host &apos;%1&apos; can&apos;t be established.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Are you sure you want to continue connecting ?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>SHA1 Fingerprint: %1.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
